/**
 * FileName: StudyClient
 * Author:   wenjunlong
 * Date:     2018/5/3 15:22
 * Description: 学习日志feign接口服务
 * History:
 * <author>          <time>          <version>          <desc>
 * 作者姓名           修改时间           版本号              描述
 */
package com.yizhi.studylog.application.feign;

import com.yizhi.studylog.application.vo.StudyLogVo;
import com.yizhi.studylog.application.vo.TpStudentActivityRecordVo;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * 〈一句话功能简述〉<br> 
 * 〈学习日志feign接口服务〉
 *
 * @author wenjunlong
 * @create 2018/5/3
 * @since 1.0.0
 */
@FeignClient(name = "studyLog", contextId = "StudyLogClient")
public interface StudyLogClient {


    /**
     * 获取未分析的学习日志
     * @return
     */
    @GetMapping("/studyLog/list")
    List<StudyLogVo> list(@RequestParam("type") String type);

    /**
     * 获取未分析的学习日志sessionId(指定开始时间)
     * @param maxId
     * @return
     */
    @GetMapping("/studyLog/startId/list/sessionId")
    List<String> listSessionId(@RequestParam("maxId") Long maxId);
    /**
     * 获取最大的id数据
     * @return
     */
    @GetMapping("/studyLog/id/max")
    Long maxId();

    /**
     * 获取最大的id数据
     * @return
     */
    @GetMapping("/studyLog/id/min")
    Long minId();
    /**
     * 获取sessionId为纬度的分组数据
     * @param maxId
     * @param sessionId
     * @return
     */
    @GetMapping("/studyLog/sessionId/recode/get")
    List<StudyLogVo> getRecodeBySessionId(@RequestParam(value = "maxId" ,required = false) Long maxId, @RequestParam("sessionId") String sessionId);


    /**
     * 将已分析的学习日志状态status 置为 1 批量进行
     * @param studyLogs
     * @return
     */
    @PostMapping("/studyLog/list/update")
    Boolean updateList(@RequestBody List<StudyLogVo> studyLogs);

    /**
     * 删除 已经解析完成的日志
     * @return
     */
    @PostMapping("/studyLog/delete/batch")
    Boolean deleteBatch(@RequestBody List<Long> ids);
    
    
    /**
     * 保留原始记录，如果消息丢失可以通过反查机制
     * @param tsar
     * @return
     */
    @PostMapping("/studyLog/recorde/insert/batch")
    Boolean insertRecoreds(@RequestBody TpStudentActivityRecordVo tsar);

    /**
     * 根据课程id查询心跳记录条数
     * @param courseId
     * @return
     */
    @GetMapping("/studyLog/get/courseId")
    int getStudyLogByCourseId(@RequestParam("courseId")  Long courseId);


}
