package com.yizhi.studylog.application.controller;


import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.toolkit.CollectionUtils;
import com.yizhi.application.orm.id.IdGenerator;
import com.yizhi.application.orm.util.QueryUtil;
import com.yizhi.studylog.application.domain.StudyLog;
import com.yizhi.studylog.application.domain.TpStudentActivityRecord;
import com.yizhi.studylog.application.service.IStudyLogService;
import com.yizhi.studylog.application.service.ITpStudentActivityRecordService;
import com.yizhi.studylog.application.vo.StudyLogVo;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

/**
 * <p>
 * 学习日志表 前端控制器
 * </p>
 *
 * @author fulan123
 * @since 2018-05-03
 */
@RestController
@RequestMapping("/studyLog")
public class StudyLogController {

    @Autowired
    IStudyLogService studyLogService;

    @Autowired
    IdGenerator idGenerator;
    
    @Autowired
    ITpStudentActivityRecordService tpStudentActivityRecordService;


    @GetMapping("/list")
    public List<StudyLogVo> list(@RequestParam("type") String type){
        List<StudyLog> studyLogs = studyLogService.selectStudyLogList(type);
        List<StudyLogVo> studyLogVoList = new ArrayList<>();
        if(CollectionUtils.isNotEmpty(studyLogs)){
            for (StudyLog studyLog : studyLogs){
                StudyLogVo studyLogVo = new StudyLogVo();
                BeanUtils.copyProperties(studyLog, studyLogVo);
                studyLogVoList.add(studyLogVo);
            }
        }
        return studyLogVoList;
    }

    /**
     * 获取未分析的学习日志sessionId(指定开始时间)
     * @param maxId
     * @return
     */
    @GetMapping("/startId/list/sessionId")
    public List<String> listSessionId(@RequestParam("maxId") Long maxId){

        if(Objects.isNull(maxId) || maxId.longValue() <= 0){
            return null;
        }
        return studyLogService.listSessionId(maxId);
    }

    /**
     * 获取最大的id数据
     * @return
     */
    @GetMapping("/id/max")
    public Long maxId(){
        return studyLogService.maxId();
    }

    /**
     * 获取最小的id数据
     * @return
     */
    @GetMapping("/id/min")
    public Long minId(){
        return studyLogService.minId();
    }

    /**
     * 获取sessionId为纬度的分组数据
     * @param maxId
     * @param sessionId
     * @return
     */
    @GetMapping("/sessionId/recode/get")
    public List<StudyLogVo> getRecodeBySessionId(@RequestParam(value = "maxId" ,required = false) Long maxId, @RequestParam("sessionId") String sessionId){

        if((Objects.isNull(maxId) || maxId.longValue() <= 0) && StringUtils.isBlank(sessionId)){
            return null;
        }
        EntityWrapper<StudyLog> ew = QueryUtil.condition(new StudyLog());
        if(Objects.nonNull(maxId) && maxId.longValue()>0){
            ew.le("id",maxId);
        }
        ew.eq("session_id",sessionId);
        ew.orderBy("id", false);
        List<StudyLogVo> studyLogVoList = new ArrayList<>();
        if(CollectionUtils.isNotEmpty(studyLogService.selectList(ew))){
            for (StudyLog studyLog : studyLogService.selectList(ew)){
                StudyLogVo studyLogVo = new StudyLogVo();
                BeanUtils.copyProperties(studyLog, studyLogVo);
                studyLogVoList.add(studyLogVo);
            }
        }
        return studyLogVoList;
    }

    @PostMapping("/list/update")
    public Boolean updateList(@RequestBody List<StudyLog> studyLogs ){
        Boolean f = studyLogService.insertBatch(studyLogs,500);
        return f;
    }

    @PostMapping("/delete/batch")
    public Boolean deleteBatch(@RequestBody List<Long> ids){
        Boolean f = studyLogService.deleteBatchIds(ids);
        return f;
    }
    
    
    //因为异步消息可能会丢失，加这个可以通过反查机制查询
    @PostMapping("/recorde/insert/batch")
    public Boolean recordeInsertBatch(@RequestBody TpStudentActivityRecord tsar) {
    	return tpStudentActivityRecordService.insert(tsar);
    }

    @GetMapping("/get/courseId")
    public int getStudyLogByCourseId(@RequestParam("courseId")  Long courseId){
        StudyLog studyLog = new StudyLog();
        studyLog.setCourseId(courseId);
        return studyLogService.selectCount(QueryUtil.condition(studyLog));
    }
}

